BugReport class
Constructors
-
BugReport({String? id, String? description = '', String? stepsToReproduce, String? userIdentifier, String? createdAt, String? updatedAt, List<
Attachment> ? attachments, Device? device, App? app, AppVersion? appVersion}) - BugReport.create({required String? description, required String? stepsToReproduce, String? userIdentifier = 'No user id provided'})
-
BugReport.fromJson(Map<
String, dynamic> json) -
factory
Properties
- app ↔ App?
-
getter/setter pair
- appVersion ↔ AppVersion?
-
getter/setter pair
-
attachments
↔ List<
Attachment> ? -
getter/setter pair
- createdAt ↔ String?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- device ↔ Device?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepsToReproduce ↔ String?
-
getter/setter pair
- updatedAt ↔ String?
-
getter/setter pair
- userIdentifier ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited