Api class
Constructors
- Api()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deviceStatus(
) → Future< Map< String, String> > -
ping(
PingRequest pingRequest) → Future< AppInstall> -
resetBaseUrl(
) → void -
resetDeviceStatusProvider(
) → void - Resets the device status provider to the default.
-
resetHttpClient(
) → void - Resets the HTTP client to the default.
-
setBaseUrl(
String url) → void -
setDeviceStatusProvider(
DeviceStatusProvider provider) → void - Sets a custom device status provider (useful for testing).
-
setHttpClient(
Client client) → void - Sets a custom HTTP client (useful for testing).
-
submitReport(
BugReportRequest submitReportRequest, {LogBuffer? logBuffer}) → Future< BugReport>