Critic class
Constructors
- Critic()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logCapture → LogCapture
-
Log capture instance. Access the underlying LogBuffer via
Critic().logCapture.bufferif you need to add custom entries.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initialize(
String apiToken, {String? baseUrl}) → Future< Zone> -
initializeAndRun(
String apiToken, void body(), {String? baseUrl}) → Future< void> -
Initializes the SDK and runs
bodyinside the log-capture zone so that allprint()calls are automatically captured. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
submitReport(
BugReport report) → Future< BugReport> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited